@@ -74,12 +74,18 @@ macro_rules! impl_dyn_series {
                     .map(|ca| ca.$into_logical().into_series())
             }
 
-            fn vec_hash(&self, random_state: RandomState) -> Vec<u64> {
-                self.0.vec_hash(random_state)
+            fn vec_hash(&self, random_state: RandomState, buf: &mut Vec<u64>) -> PolarsResult<()> {
+                self.0.vec_hash(random_state, buf);
+                Ok(())
             }
 
-            fn vec_hash_combine(&self, build_hasher: RandomState, hashes: &mut [u64]) {
-                self.0.vec_hash_combine(build_hasher, hashes)
+            fn vec_hash_combine(
+                &self,
+                build_hasher: RandomState,
+                hashes: &mut [u64],
+            ) -> PolarsResult<()> {
+                self.0.vec_hash_combine(build_hasher, hashes);
+                Ok(())
             }
 
             unsafe fn agg_min(&self, groups: &GroupsProxy) -> Series {
@@ -98,22 +104,6 @@ macro_rules! impl_dyn_series {
                     .unwrap()
             }
 
-            unsafe fn agg_quantile(
-                &self,
-                groups: &GroupsProxy,
-                quantile: f64,
-                interpol: QuantileInterpolOptions,
-            ) -> Series {
-                self.0
-                    .agg_quantile(groups, quantile, interpol)
-                    .$into_logical()
-                    .into_series()
-            }
-
-            unsafe fn agg_median(&self, groups: &GroupsProxy) -> Series {
-                self.0.agg_median(groups).$into_logical().into_series()
-            }
-
             fn zip_outer_join_column(
                 &self,
                 right_column: &Series,
@@ -177,7 +167,7 @@ macro_rules! impl_dyn_series {
                     "cannot do remainder operation on logical".into(),
                 ))
             }
-            fn group_tuples(&self, multithreaded: bool, sorted: bool) -> GroupsProxy {
+            fn group_tuples(&self, multithreaded: bool, sorted: bool) -> PolarsResult<GroupsProxy> {
                 self.0.group_tuples(multithreaded, sorted)
             }
             #[cfg(feature = "sort_multiple")]
