@@ -1,8 +1,6 @@
 use std::any::Any;
 use std::borrow::Cow;
 
-use polars_arrow::prelude::QuantileInterpolOptions;
-
 use super::{private, IntoSeries, SeriesTrait};
 use crate::chunked_array::comparison::*;
 use crate::chunked_array::ops::explode::ExplodeByOffsets;
@@ -220,23 +218,6 @@ impl SeriesTrait for SeriesWrap<ListChunked> {
     fn min_as_series(&self) -> Series {
         ChunkAggSeries::min_as_series(&self.0)
     }
-    fn median_as_series(&self) -> Series {
-        QuantileAggSeries::median_as_series(&self.0)
-    }
-    fn var_as_series(&self, ddof: u8) -> Series {
-        VarAggSeries::var_as_series(&self.0, ddof)
-    }
-    fn std_as_series(&self, ddof: u8) -> Series {
-        VarAggSeries::std_as_series(&self.0, ddof)
-    }
-    fn quantile_as_series(
-        &self,
-        quantile: f64,
-        interpol: QuantileInterpolOptions,
-    ) -> PolarsResult<Series> {
-        QuantileAggSeries::quantile_as_series(&self.0, quantile, interpol)
-    }
-
     fn fmt_list(&self) -> String {
         FmtList::fmt_list(&self.0)
     }
