@@ -1,3 +1,5 @@
+#[cfg(feature = "dtype-binary")]
+mod binary;
 mod boolean;
 #[cfg(feature = "dtype-categorical")]
 mod categorical;
@@ -129,8 +131,9 @@ macro_rules! impl_dyn_series {
                 (&self.0).into_partial_ord_inner()
             }
 
-            fn vec_hash(&self, random_state: RandomState) -> PolarsResult<Vec<u64>> {
-                Ok(self.0.vec_hash(random_state))
+            fn vec_hash(&self, random_state: RandomState, buf: &mut Vec<u64>) -> PolarsResult<()> {
+                self.0.vec_hash(random_state, buf);
+                Ok(())
             }
 
             fn vec_hash_combine(
@@ -567,6 +570,8 @@ impl<T: PolarsNumericType> private::PrivateSeriesNumeric for SeriesWrap<ChunkedA
 }
 
 impl private::PrivateSeriesNumeric for SeriesWrap<Utf8Chunked> {}
+#[cfg(feature = "dtype-binary")]
+impl private::PrivateSeriesNumeric for SeriesWrap<BinaryChunked> {}
 impl private::PrivateSeriesNumeric for SeriesWrap<ListChunked> {}
 impl private::PrivateSeriesNumeric for SeriesWrap<BooleanChunked> {
     fn bit_repr_is_large(&self) -> bool {
