@@ -397,6 +397,8 @@ impl Debug for LiteralValue {
             Null => write!(f, "null"),
             Boolean(b) => write!(f, "{}", b),
             Utf8(s) => write!(f, "{}", s),
+            #[cfg(feature = "dtype-binary")]
+            Binary(_) => write!(f, "[binary value]"),
             #[cfg(feature = "dtype-u8")]
             UInt8(v) => write!(f, "{}u8", v),
             #[cfg(feature = "dtype-u16")]
