@@ -3,7 +3,6 @@ use polars_core::prelude::*;
 
 use crate::prelude::*;
 
-mod aggregate_pushdown;
 mod cache_states;
 #[cfg(feature = "cse")]
 mod cse;
@@ -25,7 +24,6 @@ mod slice_pushdown_lp;
 mod stack_opt;
 mod type_coercion;
 
-use aggregate_pushdown::AggregatePushdown;
 use delay_rechunk::DelayRechunk;
 use drop_nulls::ReplaceDropNulls;
 use fast_projection::FastProjectionAndCollapse;
@@ -56,6 +54,7 @@ pub fn optimize(
     opt_state: OptState,
     lp_arena: &mut Arena<ALogicalPlan>,
     expr_arena: &mut Arena<AExpr>,
+    scratch: &mut Vec<Node>,
 ) -> PolarsResult<Node> {
     // get toggle values
     let predicate_pushdown = opt_state.predicate_pushdown;
@@ -67,9 +66,6 @@ pub fn optimize(
     let cse = opt_state.common_subplan_elimination;
 
     let agg_scan_projection = opt_state.file_caching;
-    let aggregate_pushdown = opt_state.aggregate_pushdown;
-
-    let mut scratch = vec![];
 
     // gradually fill the rules passed to the optimizer
     let opt = StackOptimizer {};
@@ -103,7 +99,7 @@ pub fn optimize(
         let alp = lp_arena.take(lp_top);
         let alp = projection_pushdown_opt.optimize(alp, lp_arena, expr_arena)?;
         lp_arena.replace(lp_top, alp);
-        cache_states::set_cache_states(lp_top, lp_arena, expr_arena, &mut scratch, cse_changed);
+        cache_states::set_cache_states(lp_top, lp_arena, expr_arena, scratch, cse_changed);
     }
 
     if predicate_pushdown {
@@ -138,10 +134,6 @@ pub fn optimize(
         rules.push(Box::new(SimplifyBooleanRule {}));
     }
 
-    if aggregate_pushdown {
-        rules.push(Box::new(AggregatePushdown::new()))
-    }
-
     // make sure that we do that once slice pushdown
     // and predicate pushdown are done. At that moment
     // the file fingerprints are finished.
@@ -169,18 +161,12 @@ pub fn optimize(
         );
 
         let mut file_cacher = FileCacher::new(file_predicate_to_columns_and_count);
-        file_cacher.assign_unions(lp_top, lp_arena, expr_arena, &mut scratch);
+        file_cacher.assign_unions(lp_top, lp_arena, expr_arena, scratch);
 
         #[cfg(feature = "cse")]
         if cse_changed {
             // this must run after cse
-            cse::decrement_file_counters_by_cache_hits(
-                lp_top,
-                lp_arena,
-                expr_arena,
-                0,
-                &mut scratch,
-            );
+            cse::decrement_file_counters_by_cache_hits(lp_top, lp_arena, expr_arena, 0, scratch);
         }
     }
 
