@@ -199,7 +199,6 @@ def sequence_to_pyseries(
     """Construct a PySeries from a sequence."""
     python_dtype: type | None = None
     nested_dtype: PolarsDataType | type | None = None
-    temporal_unit: str | None = None
 
     # empty sequence
     if not values and dtype is None:
@@ -233,7 +232,6 @@ def sequence_to_pyseries(
             elif (
                 dtype in pl_temporal_types or type(dtype) in pl_temporal_types
             ) and not isinstance(value, int):
-                temporal_unit = getattr(dtype, "tu", None)
                 python_dtype = dtype_to_py_type(dtype)  # type: ignore[arg-type]
 
     # physical branch
@@ -252,8 +250,6 @@ def sequence_to_pyseries(
                 python_dtype = float
             else:
                 python_dtype = type(value)
-                if datetime == python_dtype:
-                    temporal_unit = "us"
 
         # temporal branch
         if python_dtype in py_temporal_types:
@@ -262,12 +258,23 @@ def sequence_to_pyseries(
             elif dtype in py_temporal_types:
                 dtype = py_type_to_dtype(dtype)
 
-            # if no temporal unit given, we use anyvalues, so that we have one
-            # consistent level of entry that sets the units and timezones
-            # (e.g. we ignore them). They can be set afterwards.
-            if dtype == Datetime and temporal_unit is None:
-                return PySeries.new_from_anyvalues(name, values)
+            # we use anyvalue builder to create the datetime array
+            # we store the values internally as UTC and set the timezone
+            if dtype == Datetime and value.tzinfo is not None:
+                py_series = PySeries.new_from_anyvalues(name, values)
+                tz = str(value.tzinfo)
+                return (
+                    pli.wrap_s(py_series)
+                    .dt.with_time_zone(tz)  # first inform polars of tz
+                    .dt.cast_time_zone("UTC")  # ensure we store them as utc
+                    .dt.with_time_zone(
+                        tz
+                    )  # conversion lead to utc tz, which is not correct.
+                    ._s
+                )
 
+            # TODO: use anyvalues here
+            # no need to require pyarrow for this.
             if not _PYARROW_AVAILABLE:  # pragma: no cover
                 raise ImportError(
                     "'pyarrow' is required for converting a Sequence of date or"
