@@ -7,6 +7,7 @@ from pathlib import Path
 from typing import Any, BinaryIO, ContextManager, Iterator, TextIO, overload
 from urllib.request import urlopen
 
+import polars.internals as pli
 from polars.datatypes import DataType
 from polars.utils import format_path
 
@@ -66,15 +67,15 @@ def _prepare_file_arg(
     Utility for read_[csv, parquet]. (not to be used by scan_[csv, parquet]).
     Returned value is always usable as a context.
 
-    A `StringIO`, `BytesIO` file is returned as a `BytesIO`.
+    A :class:`StringIO`, :class:`BytesIO` file is returned as a :class:`BytesIO`.
     A local path is returned as a string.
-    An http URL is read into a buffer and returned as a `BytesIO`.
+    An http URL is read into a buffer and returned as a :class:`BytesIO`.
 
     When ``encoding`` is not ``utf8`` or ``utf8-lossy``, the whole file is
     first read in python and decoded using the specified encoding and
-    returned as a `BytesIO` (for usage with ``read_csv``).
+    returned as a :class:`BytesIO` (for usage with ``read_csv``).
 
-    A `bytes` file is returned as a `BytesIO` if ``use_pyarrow=True``.
+    A `bytes` file is returned as a :class:`BytesIO` if ``use_pyarrow=True``.
 
     When fsspec is installed, remote file(s) is (are) opened with
     `fsspec.open(file, **kwargs)` or `fsspec.open_files(file, **kwargs)`.
@@ -185,3 +186,13 @@ def _is_local_file(file: str) -> bool:
         return True
     except StopIteration:
         return False
+
+
+def _update_columns(df: pli.DataFrame, new_columns: list[str]) -> pli.DataFrame:
+    if df.width > len(new_columns):
+        cols = df.columns
+        for i, name in enumerate(new_columns):
+            cols[i] = name
+        new_columns = cols
+    df.columns = new_columns
+    return df
