@@ -144,13 +144,15 @@ def range_to_slice(rng: range) -> slice:
 
 
 def handle_projection_columns(
-    columns: list[str] | list[int] | None,
+    columns: Sequence[str] | Sequence[int] | str | None,
 ) -> tuple[list[int] | None, list[str] | None]:
     """Disambiguates between columns specified as integers vs. strings."""
     projection: list[int] | None = None
     if columns:
-        if is_int_sequence(columns):
-            projection = columns  # type: ignore[assignment]
+        if isinstance(columns, str):
+            columns = [columns]
+        elif is_int_sequence(columns):
+            projection = list(columns)
             columns = None
         elif not is_str_sequence(columns):
             raise ValueError(
@@ -195,6 +197,7 @@ def _prepare_row_count_args(
 
 
 EPOCH = datetime(1970, 1, 1).replace(tzinfo=None)
+UTC = zoneinfo.ZoneInfo("UTC")
 
 
 def _to_python_datetime(
@@ -211,7 +214,7 @@ def _to_python_datetime(
         dt += timedelta(seconds=value * 3600 * 24)
         return dt.date()
     elif dtype == Datetime:
-        if tz is None or tz == "" or tz == "UTC":
+        if tz is None or tz == "":
             if tu == "ns":
                 # nanoseconds to seconds
                 dt = EPOCH + timedelta(microseconds=value / 1000)
@@ -225,16 +228,18 @@ def _to_python_datetime(
         else:
             if tu == "ns":
                 # nanoseconds to seconds
-                dt = datetime.fromtimestamp(0) + timedelta(microseconds=value / 1000)
+                dt = datetime.fromtimestamp(0, tz=UTC) + timedelta(
+                    microseconds=value / 1000
+                )
             elif tu == "us":
-                dt = datetime.fromtimestamp(0) + timedelta(microseconds=value)
+                dt = datetime.fromtimestamp(0, tz=UTC) + timedelta(microseconds=value)
             elif tu == "ms":
                 # milliseconds to seconds
-                dt = datetime.fromtimestamp(value / 1000)
+                dt = datetime.fromtimestamp(value / 1000, tz=UTC)
             else:
                 raise ValueError(f"tu must be one of {{'ns', 'us', 'ms'}}, got {tu}")
-
             return _localize(dt, tz)
+
         return dt
     else:
         raise NotImplementedError  # pragma: no cover
@@ -269,7 +274,7 @@ def format_path(path: str | Path) -> str:
 
 
 def threadpool_size() -> int:
-    """Get the size of polars; thread pool."""
+    """Get the size of polars' thread pool."""
     return _pool_size()
 
 
