@@ -1,3 +1,4 @@
+use std::collections::BTreeSet;
 use std::fmt::{Display, Formatter};
 use std::hash::{Hash, Hasher};
 
@@ -17,7 +18,7 @@ use pyo3::basic::CompareOp;
 use pyo3::conversion::{FromPyObject, IntoPy};
 use pyo3::exceptions::PyValueError;
 use pyo3::prelude::*;
-use pyo3::types::{PyBool, PyDict, PyList, PySequence};
+use pyo3::types::{PyBool, PyBytes, PyDict, PyList, PySequence};
 use pyo3::{PyAny, PyResult};
 
 use crate::dataframe::PyDataFrame;
@@ -136,6 +137,22 @@ impl<'a> FromPyObject<'a> for Wrap<Utf8Chunked> {
     }
 }
 
+impl<'a> FromPyObject<'a> for Wrap<BinaryChunked> {
+    fn extract(obj: &'a PyAny) -> PyResult<Self> {
+        let (seq, len) = get_pyseq(obj)?;
+        let mut builder = BinaryChunkedBuilder::new("", len, len * 25);
+
+        for res in seq.iter()? {
+            let item = res?;
+            match item.extract::<&str>() {
+                Ok(val) => builder.append_value(val),
+                Err(_) => builder.append_null(),
+            }
+        }
+        Ok(Wrap(builder.finish()))
+    }
+}
+
 impl<'a> FromPyObject<'a> for Wrap<NullValues> {
     fn extract(ob: &'a PyAny) -> PyResult<Self> {
         if let Ok(s) = ob.extract::<String>() {
@@ -214,7 +231,12 @@ impl IntoPy<PyObject> for Wrap<AnyValue<'_>> {
                     TimeUnit::Milliseconds => convert.call1((v, "ms")).unwrap().into_py(py),
                 }
             }
-            AnyValue::Time(v) => v.into_py(py),
+            AnyValue::Time(v) => {
+                let pl = PyModule::import(py, "polars").unwrap();
+                let utils = pl.getattr("utils").unwrap();
+                let convert = utils.getattr("_to_python_time").unwrap();
+                convert.call1((v,)).unwrap().into_py(py)
+            }
             AnyValue::List(v) => PySeries::new(v).to_list(),
             AnyValue::Struct(vals, flds) => struct_dict(py, vals, flds),
             AnyValue::StructOwned(payload) => struct_dict(py, payload.0, &payload.1),
@@ -223,6 +245,8 @@ impl IntoPy<PyObject> for Wrap<AnyValue<'_>> {
                 let s = format!("{}", v);
                 s.into_py(py)
             }
+            AnyValue::Binary(v) => v.into_py(py),
+            AnyValue::BinaryOwned(v) => v.into_py(py),
         }
     }
 }
@@ -244,6 +268,7 @@ impl ToPyObject for Wrap<DataType> {
             DataType::Float64 => pl.getattr("Float64").unwrap().into(),
             DataType::Boolean => pl.getattr("Boolean").unwrap().into(),
             DataType::Utf8 => pl.getattr("Utf8").unwrap().into(),
+            DataType::Binary => pl.getattr("Binary").unwrap().into(),
             DataType::List(inner) => {
                 let inner = Wrap(*inner.clone()).to_object(py);
                 let list_class = pl.getattr("List").unwrap();
@@ -308,6 +333,7 @@ impl FromPyObject<'_> for Wrap<DataType> {
                     "Int32" => DataType::Int32,
                     "Int64" => DataType::Int64,
                     "Utf8" => DataType::Utf8,
+                    "Binary" => DataType::Binary,
                     "Boolean" => DataType::Boolean,
                     "Categorical" => DataType::Categorical(None),
                     "Date" => DataType::Date,
@@ -391,6 +417,16 @@ impl ToPyObject for Wrap<&Utf8Chunked> {
     }
 }
 
+impl ToPyObject for Wrap<&BinaryChunked> {
+    fn to_object(&self, py: Python) -> PyObject {
+        let iter = self
+            .0
+            .into_iter()
+            .map(|opt_bytes| opt_bytes.map(|bytes| PyBytes::new(py, bytes)));
+        PyList::new(py, iter).into_py(py)
+    }
+}
+
 impl ToPyObject for Wrap<&StructChunked> {
     fn to_object(&self, py: Python) -> PyObject {
         let s = self.0.clone().into_series();
@@ -433,11 +469,12 @@ impl ToPyObject for Wrap<&DatetimeChunked> {
         let py_date_dtype = pl.getattr("Datetime").unwrap();
 
         let tu = Wrap(self.0.time_unit()).to_object(py);
+        let tz = self.0.time_zone().to_object(py);
 
         let iter = self
             .0
             .into_iter()
-            .map(|opt_v| opt_v.map(|v| convert.call1((v, py_date_dtype, &tu)).unwrap()));
+            .map(|opt_v| opt_v.map(|v| convert.call1((v, py_date_dtype, &tu, &tz)).unwrap()));
         PyList::new(py, iter).into_py(py)
     }
 }
@@ -480,7 +517,7 @@ impl<'s> FromPyObject<'s> for Wrap<AnyValue<'s>> {
             Ok(AnyValue::Float64(v).into())
         } else if let Ok(v) = ob.extract::<&'s str>() {
             Ok(AnyValue::Utf8(v).into())
-        } else if ob.get_type().name()?.contains("datetime") {
+        } else if ob.get_type().name()?.eq("datetime") {
             Python::with_gil(|py| {
                 // windows
                 #[cfg(target_arch = "windows")]
@@ -544,7 +581,7 @@ impl<'s> FromPyObject<'s> for Wrap<AnyValue<'s>> {
             let py_pyseries = ob.getattr("_s").unwrap();
             let series = py_pyseries.extract::<PySeries>().unwrap().series;
             Ok(Wrap(AnyValue::List(series)))
-        } else if ob.get_type().name()?.contains("date") {
+        } else if ob.get_type().name()?.eq("date") {
             Python::with_gil(|py| {
                 let date = py_modules::UTILS
                     .getattr(py, "_date_to_pl_date")
@@ -554,7 +591,7 @@ impl<'s> FromPyObject<'s> for Wrap<AnyValue<'s>> {
                 let v = date.extract::<i32>(py).unwrap();
                 Ok(Wrap(AnyValue::Date(v)))
             })
-        } else if ob.get_type().name()?.contains("timedelta") {
+        } else if ob.get_type().name()?.eq("timedelta") {
             Python::with_gil(|py| {
                 let td = py_modules::UTILS
                     .getattr(py, "_timedelta_to_pl_timedelta")
@@ -564,9 +601,21 @@ impl<'s> FromPyObject<'s> for Wrap<AnyValue<'s>> {
                 let v = td.extract::<i64>(py).unwrap();
                 Ok(Wrap(AnyValue::Duration(v, TimeUnit::Microseconds)))
             })
+        } else if ob.get_type().name()?.eq("time") {
+            Python::with_gil(|py| {
+                let time = py_modules::UTILS
+                    .getattr(py, "_time_to_pl_time")
+                    .unwrap()
+                    .call1(py, (ob,))
+                    .unwrap();
+                let v = time.extract::<i64>(py).unwrap();
+                Ok(Wrap(AnyValue::Time(v)))
+            })
+        } else if let Ok(v) = ob.extract::<&'s [u8]>() {
+            Ok(AnyValue::Binary(v).into())
         } else {
             Err(PyErr::from(PyPolarsErr::Other(format!(
-                "row type not supported {:?}",
+                "object type not supported {:?}",
                 ob
             ))))
         }
@@ -702,35 +751,42 @@ impl<'a, T: NativeType + FromPyObject<'a>> FromPyObject<'a> for Wrap<Vec<T>> {
     }
 }
 
-pub(crate) fn dicts_to_rows(records: &PyAny) -> PyResult<(Vec<Row>, Vec<String>)> {
+pub(crate) fn dicts_to_rows(
+    records: &PyAny,
+    infer_schema_len: usize,
+) -> PyResult<(Vec<Row>, Vec<String>)> {
     let (dicts, len) = get_pyseq(records)?;
+
+    let mut key_names = BTreeSet::new();
+    for d in dicts.iter()?.take(infer_schema_len) {
+        let d = d?;
+        let d = d.downcast::<PyDict>()?;
+        let keys = d.keys();
+
+        for name in keys {
+            let name = name.extract::<String>()?;
+            key_names.insert(name);
+        }
+    }
+
     let mut rows = Vec::with_capacity(len);
 
-    let mut iter = dicts.iter()?;
-    let d = iter.next().unwrap()?;
-    let d = d.downcast::<PyDict>()?;
-    let vals = d.values();
-    let keys_first = d.keys().extract::<Vec<String>>()?;
-    let row = vals.extract::<Wrap<Row>>()?.0;
-    rows.push(row);
-
-    let keys = d.keys();
-    let width = keys.len();
-
-    for d in iter {
+    for d in dicts.iter()? {
         let d = d?;
         let d = d.downcast::<PyDict>()?;
 
-        let mut row = Vec::with_capacity(width);
+        let mut row = Vec::with_capacity(key_names.len());
 
-        for k in keys {
-            let val = d.get_item(k).unwrap();
-            let val = val.extract::<Wrap<AnyValue>>()?.0;
+        for k in key_names.iter() {
+            let val = match d.get_item(k) {
+                None => AnyValue::Null,
+                Some(val) => val.extract::<Wrap<AnyValue>>()?.0,
+            };
             row.push(val)
         }
         rows.push(Row(row))
     }
-    Ok((rows, keys_first))
+    Ok((rows, key_names.into_iter().collect()))
 }
 
 #[cfg(feature = "asof_join")]
