@@ -6,6 +6,8 @@ extern crate polars;
 
 pub mod apply;
 pub mod arrow_interop;
+#[cfg(feature = "csv-file")]
+mod batched_csv;
 pub mod conversion;
 pub mod dataframe;
 pub mod datatypes;
@@ -18,7 +20,7 @@ pub mod prelude;
 pub(crate) mod py_modules;
 pub mod series;
 mod set;
-#[cfg(feature = "polars-sql")]
+#[cfg(feature = "sql")]
 mod sql;
 pub mod utils;
 
@@ -29,7 +31,7 @@ use lazy::ToExprs;
 use mimalloc::MiMalloc;
 use polars::functions::{diag_concat_df, hor_concat_df};
 use polars::prelude::Null;
-use polars_core::datatypes::TimeUnit;
+use polars_core::datatypes::{TimeUnit, TimeZone};
 use polars_core::prelude::{DataFrame, IntoSeries, IDX_DTYPE};
 use polars_core::POOL;
 use pyo3::exceptions::PyValueError;
@@ -451,10 +453,19 @@ fn py_date_range(
     closed: Wrap<ClosedWindow>,
     name: &str,
     tu: Wrap<TimeUnit>,
+    tz: Option<TimeZone>,
 ) -> PySeries {
-    polars::time::date_range_impl(name, start, stop, Duration::parse(every), closed.0, tu.0)
-        .into_series()
-        .into()
+    polars::time::date_range_impl(
+        name,
+        start,
+        stop,
+        Duration::parse(every),
+        closed.0,
+        tu.0,
+        tz,
+    )
+    .into_series()
+    .into()
 }
 
 #[pyfunction]
@@ -528,7 +539,9 @@ fn polars(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<PyLazyFrame>().unwrap();
     m.add_class::<PyLazyGroupBy>().unwrap();
     m.add_class::<dsl::PyExpr>().unwrap();
-    #[cfg(feature = "polars-sql")]
+    #[cfg(feature = "csv-file")]
+    m.add_class::<batched_csv::PyBatchedCsv>().unwrap();
+    #[cfg(feature = "sql")]
     m.add_class::<sql::PySQLContext>().unwrap();
     m.add_wrapped(wrap_pyfunction!(col)).unwrap();
     m.add_wrapped(wrap_pyfunction!(count)).unwrap();
