@@ -51,10 +51,8 @@ def test_apply_none() -> None:
 
 def test_apply_return_py_object() -> None:
     df = pl.DataFrame({"A": [1, 2, 3], "B": [4, 5, 6]})
-
     out = df.select([pl.all().map(lambda s: reduce(lambda a, b: a + b, s))])
-
-    assert out.shape == (1, 2)
+    assert out.rows() == [(6, 15)]
 
 
 @no_type_check
@@ -241,3 +239,25 @@ def test_apply_skip_nulls() -> None:
 
     assert s.apply(lambda x: some_map[x]).to_list() == [None, "b"]
     assert s.apply(lambda x: some_map[x], skip_nulls=False).to_list() == ["a", "b"]
+
+
+def test_apply_object_dtypes() -> None:
+    assert pl.DataFrame(
+        {"a": pl.Series([1, 2, "a", 4, 5], dtype=pl.Object)}
+    ).with_columns(
+        [
+            pl.col("a").apply(lambda x: x * 2, return_dtype=pl.Object),
+            pl.col("a")
+            .apply(lambda x: isinstance(x, (int, float)), return_dtype=pl.Boolean)
+            .alias("is_numeric1"),
+            pl.col("a")
+            .apply(lambda x: isinstance(x, (int, float)))
+            .alias("is_numeric_infer"),
+        ]
+    ).to_dict(
+        False
+    ) == {
+        "a": [2, 4, "aa", 8, 10],
+        "is_numeric1": [True, True, False, True, True],
+        "is_numeric_infer": [True, True, False, True, True],
+    }
