@@ -12,9 +12,16 @@ import pyarrow as pa
 import pytest
 
 import polars as pl
+from polars.datatypes import DTYPE_TEMPORAL_UNITS
 from polars.exceptions import NoRowsReturned, TooManyRowsReturned
 from polars.testing import assert_frame_equal, assert_series_equal, columns
 
+if sys.version_info >= (3, 9):
+    from zoneinfo import ZoneInfo
+else:
+    from backports.zoneinfo import ZoneInfo
+
+
 if TYPE_CHECKING:
     from polars.internals.type_aliases import JoinStrategy
 
@@ -484,11 +491,15 @@ def test_groupby() -> None:
         df.groupby("a", "b")  # type: ignore[arg-type]
 
 
-BAD_AGG_PARAMETERS = [[("b", "sum")], [("b", ["sum"])], {"b": "sum"}, {"b": ["sum"]}]
-GOOD_AGG_PARAMETERS: list[pl.Expr | list[pl.Expr]] = [
-    [pl.col("b").sum()],
-    pl.col("b").sum(),
-]
+def bad_agg_parameters() -> Any:
+    return [[("b", "sum")], [("b", ["sum"])], {"b": "sum"}, {"b": ["sum"]}]
+
+
+def good_agg_parameters() -> list[pl.Expr | list[pl.Expr]]:
+    return [
+        [pl.col("b").sum()],
+        pl.col("b").sum(),
+    ]
 
 
 @pytest.mark.parametrize("lazy", [True, False])
@@ -496,15 +507,15 @@ def test_groupby_agg_input_types(lazy: bool) -> None:
     df = pl.DataFrame({"a": [1, 1, 2, 2], "b": [1, 2, 3, 4]})
     df_or_lazy: pl.DataFrame | pl.LazyFrame = df.lazy() if lazy else df
 
-    for bad_param in BAD_AGG_PARAMETERS:
+    for bad_param in bad_agg_parameters():
         with pytest.raises(TypeError):
-            result = df_or_lazy.groupby("a").agg(bad_param)  # type: ignore[arg-type]
+            result = df_or_lazy.groupby("a").agg(bad_param)
             if lazy:
                 result.collect()  # type: ignore[union-attr]
 
     expected = pl.DataFrame({"a": [1, 2], "b": [3, 7]})
 
-    for good_param in GOOD_AGG_PARAMETERS:
+    for good_param in good_agg_parameters():
         result = df_or_lazy.groupby("a", maintain_order=True).agg(good_param)
         if lazy:
             result = result.collect()  # type: ignore[union-attr]
@@ -516,19 +527,17 @@ def test_groupby_rolling_agg_input_types(lazy: bool) -> None:
     df = pl.DataFrame({"index_column": [0, 1, 2, 3], "b": [1, 3, 1, 2]})
     df_or_lazy: pl.DataFrame | pl.LazyFrame = df.lazy() if lazy else df
 
-    for bad_param in BAD_AGG_PARAMETERS:
+    for bad_param in bad_agg_parameters():
         with pytest.raises(TypeError):
             result = df_or_lazy.groupby_rolling(
                 index_column="index_column", period="2i"
-            ).agg(
-                bad_param  # type: ignore[arg-type]
-            )
+            ).agg(bad_param)
             if lazy:
                 result.collect()  # type: ignore[union-attr]
 
     expected = pl.DataFrame({"index_column": [0, 1, 2, 3], "b": [1, 4, 4, 3]})
 
-    for good_param in GOOD_AGG_PARAMETERS:
+    for good_param in good_agg_parameters():
         result = df_or_lazy.groupby_rolling(
             index_column="index_column", period="2i"
         ).agg(good_param)
@@ -542,19 +551,17 @@ def test_groupby_dynamic_agg_input_types(lazy: bool) -> None:
     df = pl.DataFrame({"index_column": [0, 1, 2, 3], "b": [1, 3, 1, 2]})
     df_or_lazy: pl.DataFrame | pl.LazyFrame = df.lazy() if lazy else df
 
-    for bad_param in BAD_AGG_PARAMETERS:
+    for bad_param in bad_agg_parameters():
         with pytest.raises(TypeError):
             result = df_or_lazy.groupby_dynamic(
                 index_column="index_column", every="2i", closed="right"
-            ).agg(
-                bad_param  # type: ignore[arg-type]
-            )
+            ).agg(bad_param)
             if lazy:
                 result.collect()  # type: ignore[union-attr]
 
-    expected = pl.DataFrame({"index_column": [0, 0, 2], "b": [1, 4, 2]})
+    expected = pl.DataFrame({"index_column": [-2, 0, 2], "b": [1, 4, 2]})
 
-    for good_param in GOOD_AGG_PARAMETERS:
+    for good_param in good_agg_parameters():
         result = df_or_lazy.groupby_dynamic(
             index_column="index_column", every="2i", closed="right"
         ).agg(good_param)
@@ -674,7 +681,10 @@ def test_extend() -> None:
 
 def test_drop() -> None:
     df = pl.DataFrame({"a": [2, 1, 3], "b": ["a", "b", "c"], "c": [1, 2, 3]})
-    df = df.drop("a")
+    df = df.drop(name="a")  # type: ignore[call-arg]
+    assert df.shape == (3, 2)
+    df = pl.DataFrame({"a": [2, 1, 3], "b": ["a", "b", "c"], "c": [1, 2, 3]})
+    df = df.drop(columns="a")
     assert df.shape == (3, 2)
     df = pl.DataFrame({"a": [2, 1, 3], "b": ["a", "b", "c"], "c": [1, 2, 3]})
     s = df.drop_in_place("a")
@@ -1371,8 +1381,12 @@ def test_hashing_on_python_objects() -> None:
 
 
 def test_unique_unit_rows() -> None:
-    # simply test if we don't panic.
-    pl.DataFrame({"a": [1], "b": [None]}).unique(subset="a")
+    df = pl.DataFrame({"a": [1], "b": [None]})
+
+    # 'unique' one-row frame should be equal to the original frame
+    assert df.frame_equal(df.unique(subset="a"))
+    for col in df.columns:
+        assert df.n_unique(subset=[col]) == 1
 
 
 def test_panic() -> None:
@@ -1731,7 +1745,30 @@ def test_is_duplicated() -> None:
 
 def test_is_unique() -> None:
     df = pl.DataFrame({"foo": [1, 2, 2], "bar": [6, 7, 7]})
+
     assert df.is_unique().series_equal(pl.Series("", [True, False, False]))
+    assert df.unique(maintain_order=True).rows() == [(1, 6), (2, 7)]
+    assert df.n_unique() == 2
+
+
+def test_n_unique_subsets() -> None:
+    df = pl.DataFrame(
+        {
+            "a": [1, 1, 2, 3, 4, 5],
+            "b": [0.5, 0.5, 1.0, 2.0, 3.0, 3.0],
+            "c": [True, True, True, False, True, True],
+        }
+    )
+    # omitting 'subset' counts unique rows
+    assert df.n_unique() == 5
+
+    # providing it counts unique col/expr subsets
+    assert df.n_unique(subset=["b", "c"]) == 4
+    assert df.n_unique(subset=pl.col("c")) == 2
+    assert (
+        df.n_unique(subset=[(pl.col("a") // 2), (pl.col("c") | (pl.col("b") >= 2))])
+        == 3
+    )
 
 
 def test_sample() -> None:
@@ -2333,7 +2370,7 @@ def test_set() -> None:
 
     # needs to be a 2 element tuple
     with pytest.raises(ValueError):
-        df[(1, 2, 3)] = 1  # type: ignore[index]
+        df[(1, 2, 3)] = 1
 
     # we cannot index with any type, such as bool
     with pytest.raises(ValueError):
@@ -2356,3 +2393,48 @@ def test_union_with_aliases_4770() -> None:
     ).filter(pl.col("x").is_not_null())
 
     assert lf.collect()["x"].to_list() == [1, 3, 4]
+
+
+def test_init_datetimes_with_timezone() -> None:
+    tz_us = "America/New_York"
+    tz_europe = "Europe/Amsterdam"
+
+    dtm = datetime(2022, 10, 12, 12, 30, tzinfo=ZoneInfo("UTC"))
+    for tu in DTYPE_TEMPORAL_UNITS | frozenset([None]):
+        df = pl.DataFrame(
+            data={"d1": [dtm], "d2": [dtm]},
+            columns=[
+                ("d1", pl.Datetime(tu, tz_us)),
+                ("d2", pl.Datetime(tu, tz_europe)),
+            ],
+        )
+        assert (df["d1"].to_physical() == df["d2"].to_physical()).all()
+        assert df.rows() == [
+            (
+                datetime(2022, 10, 12, 8, 30, tzinfo=ZoneInfo(tz_us)),
+                datetime(2022, 10, 12, 14, 30, tzinfo=ZoneInfo(tz_europe)),
+            )
+        ]
+
+
+def test_init_physical_with_timezone() -> None:
+    tz_uae = "Asia/Dubai"
+    tz_asia = "Asia/Tokyo"
+
+    dtm_us = 1665577800000000
+    for tu in DTYPE_TEMPORAL_UNITS | frozenset([None]):
+        dtm = {"ms": dtm_us // 1_000, "ns": dtm_us * 1_000}.get(str(tu), dtm_us)
+        df = pl.DataFrame(
+            data={"d1": [dtm], "d2": [dtm]},
+            columns=[
+                ("d1", pl.Datetime(tu, tz_uae)),
+                ("d2", pl.Datetime(tu, tz_asia)),
+            ],
+        )
+        assert (df["d1"].to_physical() == df["d2"].to_physical()).all()
+        assert df.rows() == [
+            (
+                datetime(2022, 10, 12, 16, 30, tzinfo=ZoneInfo(tz_uae)),
+                datetime(2022, 10, 12, 21, 30, tzinfo=ZoneInfo(tz_asia)),
+            )
+        ]
