@@ -108,9 +108,16 @@ def test_cut() -> None:
     }
 
     # test cut on integers #4939
+    inf = float("inf")
     df = pl.DataFrame({"a": list(range(5))})
     ser = df.select("a").to_series()
-    assert pl.cut(ser, bins=[-1, 1]).shape == (5, 3)
+    assert pl.cut(ser, bins=[-1, 1]).rows() == [
+        (0.0, 1.0, "(-1.0, 1.0]"),
+        (1.0, 1.0, "(-1.0, 1.0]"),
+        (2.0, inf, "(1.0, inf]"),
+        (3.0, inf, "(1.0, inf]"),
+        (4.0, inf, "(1.0, inf]"),
+    ]
 
 
 def test_null_handling_correlation() -> None:
@@ -168,7 +175,6 @@ def test_align_frames() -> None:
         pl.from_pandas(df2.reset_index()),
         on="date",
     )
-    # (note: feels like we should be able to streamline dot-product further)
     pl_dot = (
         (pf1[["a", "b"]] * pf2[["a", "b"]])
         .fill_null(0)
@@ -200,6 +206,16 @@ def test_align_frames() -> None:
             on="date",
         )
 
+    # reverse
+    pf1, pf2 = pl.align_frames(
+        pl.DataFrame([[3, 5, 6], [5, 8, 9]], orient="row"),
+        pl.DataFrame([[2, 5, 6], [3, 8, 9], [4, 2, 0]], orient="row"),
+        on="column_0",
+        reverse=True,
+    )
+    assert pf1.rows() == [(5, 8, 9), (4, None, None), (3, 5, 6), (2, None, None)]
+    assert pf2.rows() == [(5, None, None), (4, 2, 0), (3, 8, 9), (2, 5, 6)]
+
 
 def test_nan_aggregations() -> None:
     df = pl.DataFrame({"a": [1.0, float("nan"), 2.0, 3.0], "b": [1, 1, 1, 1]})
